--[[--------------------------------------------------------------------
	SharedMedia_NoKOZHFonts

	Removes Chinese and Korean versions of Friz Quadrata TT in Western
	and Russian game locales.

	There is no reason for these fonts to be registered *by default*
	outside of Chinese and Korean game clients, as they are virtually
	identical to Friz Quadrata and just clutter up font menus with
	duplicate crap for most users.

	The few users who want to use Chinese and Korean characters in a
	Western or Russian client should install a specialized addon for
	that purpose. A general purpose library should not annoy the average
	user in order to accomodate a few users who are playing in a way the
	game client is not designed for.
----------------------------------------------------------------------]]

if GetLocale() == "koKR" or GetLocale():match("^zh") then return end

local delete = {
	["2002"] = true,
	["2002 Bold"] = true,
	["AR CrystalzcuheiGBK Demibold"] = true,
	["AR ZhongkaiGBK Medium (Combat)"] = true,
	["AR ZhongkaiGBK Medium"] = true,
}

local f = CreateFrame("Frame")
f:RegisterEvent("ADDON_LOADED")
f:SetScript("OnEvent", function()
	local LSM = LibStub("LibSharedMedia-3.0", true)
	if not LSM then return end

	f:UnregisterAllEvents()
	f:SetScript("OnEvent", nil)

	local function CleanFontList()
		local LSM = LibStub("LibSharedMedia-3.0")
		if not LSM.MediaTable.font then return end

		for name in pairs(delete) do
			LSM.MediaTable.font[name] = nil
		end

		if LSM.MediaList.font then
			for i = #LSM.MediaList.font, 1, -1 do
				if delete[LSM.MediaList.font[i]] then
					table.remove(LSM.MediaList.font, i)
				end
			end
			table.sort(LSM.MediaList.font)
		end
	end

	CleanFontList()
	LSM.RegisterCallback("SharedMedia_NoKOZHFonts", "LibSharedMedia_Registered", CleanFontList)
end)